@@ -4,7 +4,7 @@
  * LiteSpeed Web Server Cache Manager
  *
  * @author LiteSpeed Technologies, Inc. (https://www.litespeedtech.com)
- * @copyright (c) 2017-2019
+ * @copyright (c) 2017-2020
  * ******************************************* */
 
 namespace Lsc\Wp\Panel;
@@ -34,7 +34,7 @@ abstract class ControlPanel
     /**
      * @var string
      */
-    const PANEL_API_VERSION = '1.9.4';
+    const PANEL_API_VERSION = '1.9.7';
 
     /**
      * @since 1.9
@@ -106,6 +106,12 @@ abstract class ControlPanel
      */
     protected $docRootMap = null;
 
+    /**
+     * @since 1.9.7
+     * @var string
+     */
+    protected static $minAPIFilePath = '';
+
     /**
      * @var null|ControlPanel
      */
@@ -120,7 +126,7 @@ abstract class ControlPanel
         $this->phpOptions = '-d disable_functions=ini_set -d opcache.enable=0 '
                 . '-d max_execution_time=' . self::PHP_TIMEOUT . ' -d memory_limit=512M '
                 . '-d register_argc_argv=1 -d zlib.output_compression=0 -d output_handler= '
-                . '-d safe_mode=0';
+                . '-d safe_mode=0 -d open_basedir=';
 
         $this->initConfPaths();
     }
@@ -336,7 +342,16 @@ abstract class ControlPanel
      */
     public function isCacheEnabled()
     {
-        if ( ($f = fopen('/tmp/lshttpd/.status', 'r')) === false ) {
+        $statusFile = '/tmp/lshttpd/.status';
+
+        if ( !file_exists($statusFile) ) {
+            $msg = 'Cannot determine LSCache availability. Please start/switch to LiteSpeed Web '
+                    . 'Server before trying again.';
+
+            throw new LSCMException($msg, LSCMException::E_PERMISSION);
+        }
+
+        if ( ($f = fopen($statusFile, 'r')) === false ) {
             throw new LSCMException('Cannot determine LSCache availability.',
                     LSCMException::E_PERMISSION);
         }
@@ -705,6 +720,91 @@ abstract class ControlPanel
         //override in child class when needed.
     }
 
+    /**
+     *
+     * @since 1.9.7
+     */
+    protected static function setMinAPIFilePath()
+    {
+        self::$minAPIFilePath = realpath(__DIR__ . '/../..') . '/MIN_VER';
+    }
+
+    /**
+     *
+     * @since 1.9.7
+     *
+     * @return string
+     */
+    protected static function getMinAPIFilePath()
+    {
+        if ( self::$minAPIFilePath == '' ) {
+            self::setMinAPIFilePath();
+        }
+
+        return self::$minAPIFilePath;
+    }
+
+    /**
+     *
+     * @since 1.9.7
+     */
+    protected static function populateMinAPIVerFile()
+    {
+        $minVerFile = self::getMinAPIFilePath();
+
+        $minVerURL = 'https://www.litespeed.sh/sub/shared/MIN_VER';
+        $content = Util::get_url_contents($minVerURL);
+
+        if ( !empty($content) ) {
+            file_put_contents($minVerFile, $content);
+        }
+        else {
+            touch($minVerFile);
+        }
+    }
+
+    /**
+     *
+     * @since 1.9.7
+     *
+     * @return string
+     */
+    protected static function getMinAPIVer()
+    {
+        $minVerFile = self::getMinAPIFilePath();
+
+        clearstatcache();
+
+        if ( !file_exists($minVerFile)
+                || (time() - filemtime($minVerFile)) > 86400 ) {
+
+            self::populateMinAPIVerFile();
+        }
+
+        $minVer = trim(file_get_contents($minVerFile));
+
+        return $minVer;
+    }
+
+    /**
+     *
+     * @since 1.9.7
+     *
+     * @return boolean
+     */
+    public static function meetsMinAPIVerRequirement()
+    {
+        $minAPIVer = self::getMinAPIVer();
+
+        if ( $minAPIVer == ''
+                || version_compare(self::PANEL_API_VERSION, $minAPIVer, '<') ) {
+
+            return false;
+        }
+
+        return true;
+    }
+
     /**
      *
      * @since 1.9
@@ -716,6 +816,10 @@ abstract class ControlPanel
     public static function checkPanelAPICompatibility( $panelAPIVer )
     {
         $supportedAPIVers = array (
+            '1.9.7',
+            '1.9.6.1',
+            '1.9.6',
+            '1.9.5',
             '1.9.4',
             '1.9.3',
             '1.9.2',
@@ -733,13 +837,13 @@ abstract class ControlPanel
             '1.0'
         );
 
-        $maxAPIVer = $supportedAPIVers[0];
-        $minAPIVer = end($supportedAPIVers);
+        $maxSupportedAPIVer = $supportedAPIVers[0];
+        $minSupportedAPIVer = end($supportedAPIVers);
 
-        if ( version_compare($panelAPIVer, $maxAPIVer, '>') ) {
+        if ( version_compare($panelAPIVer, $maxSupportedAPIVer, '>') ) {
             return self::PANEL_API_VERSION_TOO_HIGH;
         }
-        elseif ( version_compare($panelAPIVer, $minAPIVer, '<') ) {
+        elseif ( version_compare($panelAPIVer, $minSupportedAPIVer, '<') ) {
             return self::PANEL_API_VERSION_TOO_LOW;
         }
         elseif ( ! in_array($panelAPIVer, $supportedAPIVers) ) {
